# 👷 Contributing

There are many ways you can contribute to qpsolvers. Here are some ideas:

- Add a [new solver](https://scaron.info/doc/qpsolvers/developer-notes.html#adding-a-new-solver) to the library, for instance one from the [wish list](https://github.com/qpsolvers/qpsolvers/issues?q=is%3Aissue+is%3Aopen+label%3A%22new+solver%22)
- Describe your use case in [Show and tell](https://github.com/qpsolvers/qpsolvers/discussions/categories/show-and-tell)
- Suggest improvements to the library, see for instance [these contributions](https://github.com/qpsolvers/qpsolvers/pulls?q=is%3Apr+-author%3Astephane-caron+is%3Amerged)
- Find code that is [not covered](https://coveralls.io/github/qpsolvers/qpsolvers?branch=main) by unit tests, and add a test for it
- Address one of the [open issues](https://github.com/qpsolvers/qpsolvers/issues?q=is%3Aissue+is%3Aopen)

When you contribute a PR to the library, make sure to add yourself to `CITATION.cff` and to the BibTeX citation in the readme.
